"""
PyGL3Display
(C) David Griffin (2010-present)
"Habilain" is a pseudonym used by David Griffin in a number of places.

A high performance Pygame OpenGL library, capable of handling 1000s of sprites

Requirements: Python, Pygame, PyOpenGL, Open GL 2.0 graphics hardware

Licensed under GPLv2 or GPLv3. You should have received a copy of both of these
licenses in the files GPLv2.txt and GPLv3.txt. If not these licenses can be
found at http://www.gnu.org/licenses/gpl-2.0.html (GPLv2) and
http://www.gnu.org/licenses/gpl-3.0.html (GPLv3). By using this file you agree
to be bound by at least one of these licenses.

Other licenses, including commercial/proprietary licenses, can be arranged by 
contacting me via e-mail at habilain@gmail.com. If you do not have in 
writing an alternative license agreement from me, you must use one of the 
licenses specified above when releasing work which makes use of this library.

__init__.py

Imports the most useful functions from other libraries; 99% of the time.
it should only be necessary to import from here.
"""

import OpenGL
OpenGL.FORWARD_COMPATIBLE_ONLY = True
OpenGL.UNSIGNED_BYTE_IMAGES_AS_STRING = True
del OpenGL

from pygl3display.glcommon import glConfigure
from pygl3display.glcommoninst import GLCommon
from pygl3display.infrastructure import GL3Client, GL3Shader
from pygl3display.twodshaders import (TwoDShader, TwoDVertexCamera, 
                                      TwoDFragmentCamera)
from pygl3display.twodsprites import (Surface, Sprite, AttribSprite,
     SpriteBuffer, topLeftOffsets, topRightOffsets, bottomLeftOffsets, 
     bottomRightOffsets, centerOffsets, makeAdjacentSprites, SpriteGroup,
     loadImage, SpriteCommon)
from pygl3display.twodlines import Lines
from pygl3display.twodtriangles import Triangles
from pygl3display.twodellipse import Ellipse
from pygl3display.vertexarrays import VertexArraySpec
from pygl3display.uniforms import Uniform, ProxyUniform, UniformStore
from pygl3display.onedtexture import OneDTexture
from pygl3display.twodtexture import TwoDTexture
from pygl3display.fbo import ENABLED as FBO_ENABLED
if FBO_ENABLED:
    from pygl3display.rendertargets import TwoDTextureTarget, TextureTarget


