"""
PyGL3Display
(C) David Griffin (2010-present)
"Habilain" is a pseudonym used by David Griffin in a number of places.

A high performance Pygame OpenGL library, capable of handling 1000s of sprites

Requirements: Python, Pygame, PyOpenGL, Open GL 2.0 graphics hardware

Licensed under GPLv2 or GPLv3. You should have received a copy of both of these
licenses in the files GPLv2.txt and GPLv3.txt. If not these licenses can be
found at http://www.gnu.org/licenses/gpl-2.0.html (GPLv2) and
http://www.gnu.org/licenses/gpl-3.0.html (GPLv3). By using this file you agree
to be bound by at least one of these licenses.

Other licenses, including commercial/proprietary licenses, can be arranged by 
contacting me via e-mail at habilain@gmail.com. If you do not have in physical 
writing an alternative license agreement from me, you must use one of the 
licenses specified above when releasing work which makes use of this library.

exampleskeleton.py

This file provides the basic skeleton for other, simple, examples.
"""

# Magic so that examples work if trying from an extracted archive
try:
    import pygl3display
except ImportError:
    import sys, os.path
    sys.path.append(os.path.join('..', '..'))
    import pygl3display

import pygame, math
from pygl3display import *
from pygame.locals import *


class ExampleSkeleton(object):
    def __init__(self, name, resolution):
        """Initialise the test app data"""
        self.name = name
        self.screen_resolution = resolution
        
    def init(self):
        pass
        
    def loop(self, dt):
        pass
        
    def eventHandler(self, event):
        pass
        
    def run(self, ticks=None):
        GLCommon.initEnvironment(self.screen_resolution)
        self.init()
        self.clock = pygame.time.Clock()
        self.going = True
        while self.going:
            for event in pygame.event.get():
                if event.type == QUIT or (event.type == KEYDOWN 
                   and event.key == K_ESCAPE):
                    self.going = False
                else:
                    self.eventHandler(event)
            dt = self.clock.tick(60)
            self.loop(dt)
            GLCommon.doTasks()
            if ticks is not None:
                ticks -= 1
                if ticks == 0:
                    self.going = False
        pygame.quit()
        
