"""
PyGL3Display
(C) David Griffin (2010-present)
"Habilain" is a pseudonym used by David Griffin in a number of places.

A high performance Pygame OpenGL library, capable of handling 1000s of sprites

Requirements: Python, Pygame, PyOpenGL, Open GL 2.0 graphics hardware

Licensed under GPLv2 or GPLv3. You should have received a copy of both of these
licenses in the files GPLv2.txt and GPLv3.txt. If not these licenses can be
found at http://www.gnu.org/licenses/gpl-2.0.html (GPLv2) and
http://www.gnu.org/licenses/gpl-3.0.html (GPLv3). By using this file you agree
to be bound by at least one of these licenses.

Other licenses, including commercial/proprietary licenses, can be arranged by 
contacting me via e-mail at habilain@gmail.com. If you do not have in 
writing an alternative license agreement from me, you must use one of the 
licenses specified above when releasing work which makes use of this library.

twodtextureconvertors.py

Provides some utility functions that allow simple conversion of a 2D texture
to TextureAtlas, Image or Sprite.
"""

from pygl3display.twodspriteinfrastructure import TextureAtlas2d
from pygl3display.twodspritesinterface import Sprite
import weakref

class ConverterClass(object):
    """A class which provides the facilities to convert textures to Atlases,
    Images or Sprites"""
    
    def __init__(self):
        """Initialise the convertor"""
        self.textureAtlases = weakref.WeakKeyDictionary()
        
    def textureAsAtlas(self, texture):
        """Make a texture atlas of the texture"""
        if texture not in self.textureAtlases:
            self.textureAtlases[texture] = \
                TextureAtlas2d(size = texture.size, texture = texture, 
                               rects = [])
        return self.textureAtlases[texture]
        
    def textureAsImage(self, texture, topleft = (0, 0), bottomright = None):
        """Make an image of the texture"""
        if bottomright is None:
            bottomright = (texture.size, texture.size)
        texatlas = self.textureAsAtlas(texture)
        size = texture.size
        left, top = (topleft[0] / size, topleft[1] / size)
        right, bottom = (bottomright[0] / size, bottomright[1] / size)
        return texatlas.getAtlasImage(top, bottom, left, right)
        
    def textureAsSprite(self, texture, topleft = (0, 0), bottomright = None):
        """Make a sprite of the texture; if you want to render the texture
        to screen, this is the function to use."""
        image = self.textureAsImage(texture, topleft, bottomright)
        return Sprite(image, flipx=True)

Converter = ConverterClass()
